
clear all 
close all
clc

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% REPLICATES: 
%%%     - Figure 8: Welfarist adjustment to the welfare gains from trade
%%%     - Figure 9: Costrly redistribution adjustment to welfare gains       
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% I. Setup

%%% I.I Data
addpath('CODE_EQUILIBRIUM')
load('DATA/AGI_LN_approx.mat')
load('DATA/PHI.mat')
load('DATA/BLS_CPIURS.mat')

phi_1979  = PHI_data(1,2);
phi_2007  = PHI_data(29,2);
r_2007    = lognrnd(AGI_LN(2,2),sqrt(AGI_LN(2,3)),100000,1);
k_2007    = mean(r_2007)/mean(r_2007.^(1-phi_2007));
Q_2007    = mean(r_2007);

%%% I.II Primitives
global gamma beta phi
beta        = 0.80;
% [gamma , tau_2007 , F_2007 , alpha_2007 , tau_1979] 
parameters     = [  10000        2.146          675        0.553        2.301
                     8.25       2.1465          675       0.5535       2.3005
                        4       2.1465          675       0.5535       2.2996
                      2.8        2.147          675        0.554       2.2987
                      2.4        2.147          675       0.5545       2.2982
                     1.87       2.1475          675        0.554       2.2966
                      1.6        2.148          675       0.5535        2.295
                      1.4       2.1485          675        0.553       2.2924
                      1.2       2.1495          675       0.5525       2.2859];
               
            
NN = 5;
N  = linspace(1,NN,NN)';
x0 = [  80000	1	1
        70000	5	5
        10000	10	10
        5000	25	25
        1000	50	50
        500     50	50
        500     50	50
        500     50	50
        500     50	50]';
     
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% II. Welfarist and costly redistribution corrections

%%% Figure 9
rho_grid     = [linspace(0,0.95,20),0.9999,linspace(1.05,2,20)];
welf_ms_1979 = zeros(9,41);
welf_ms_aut  = zeros(9,41);
CR_ms_1979   = zeros(9,1);
CR_ms_aut    = zeros(9,1);

for par=1:1:9
     
    gamma       = parameters(par,1);
    taug_2007   = parameters(par,2);
    Fg_2007     = parameters(par,3);
    alphag_2007 = parameters(par,4);
    taug_1979   = parameters(par,5);
    Fng         = Fg_2007*(N.^alphag_2007);
    
    phi       = phi_2007;
    [varphig] = ability_varphi(r_2007,k_2007,Q_2007,N,x0(:,par),taug_2007,Fng);
    
    [~,lg,~,rg,Qg,kg,~,~,utotg]           = k_and_Q_equilibrium(varphig,Q_2007,k_2007,taug_2007,Fng);
    [~,lga1,~,rga1,Qga1,kga1,~,~,utotga1] = k_and_Q_equilibrium(varphig,Q_2007,k_2007,taug_1979,Fng);
    [~,lga2,~,rga2,Qga2,kga2,~,~,utotga2] = k_and_Q_equilibrium(varphig,Q_2007,k_2007,10000,Fng);
    
    %%% Numbers for Figures 8 and 9
    [modstats_1979] = mod_statistics(varphig,Q_2007,k_2007,taug_2007,taug_1979,Fng,phi_2007,phi_2007,rho_grid);
    [modstats_aut]  = mod_statistics(varphig,Q_2007,k_2007,taug_2007,10000,Fng,phi_2007,phi_2007,rho_grid);
    
    welf_ms_1979(par,:) = modstats_1979(1:end-2);
    welf_ms_aut(par,:)  = modstats_aut(1:end-2);
    CR_ms_1979(par,1)   = modstats_1979(end);
    CR_ms_aut(par,1)    = modstats_aut(end);
    
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% III. Plot welfarist and costly redistribution corrections

%%% III.I Welfarist corrections
figure(1),
subplot(1,2,1),yylim = [0.65,1];
plot(rho_grid,welf_ms_1979(5,:),'b-',rho_grid,welf_ms_aut(5,:),'b--','LineWidth',2),hold on,
plot([1,1],yylim,'k--','LineWidth',1)
text([0.18],[0.80],cellstr('$\varepsilon=0.5$'),'Interpreter','Latex','fontsize',15)
ylim(yylim)
set(gca,'FontSize',12)
leg = legend(['$d_{1979}$';'$d=\infty$'])
set(leg,'Interpreter','Latex','fontsize',14)
xl  = xlabel('Degree of Risk/Inequality Aversion $\rho$'),
set(xl,'Interpreter','Latex','fontsize',14)
t   = title('Welfarist Modified Statistic')
set(t,'Interpreter','Latex','fontsize',16)

subplot(1,2,2),
plot(rho_grid,welf_ms_1979(3,:),'-','Color',[1,0,0],'LineWidth',2),hold on,
plot(rho_grid,welf_ms_aut(3,:),'--','Color',[1,0,0],'LineWidth',2),hold on,
plot(rho_grid,welf_ms_1979(7,:),'-','Color',[0.5,0,0.8],'LineWidth',2),hold on,
plot(rho_grid,welf_ms_aut(7,:),'--','Color',[0.5,0,0.8],'LineWidth',2),hold on,
plot([1,1],yylim,'k--','LineWidth',1)
ylim([0.65,1])
text([0.12,1.5],[0.76,0.85],cellstr(strvcat('$\varepsilon=0.25$','$\varepsilon=1$')),'Interpreter','Latex','fontsize',15)
set(gca,'FontSize',12)
xl  = xlabel('Degree of Risk/Inequality Aversion $\rho$'),
set(xl,'Interpreter','Latex','fontsize',14)
t   = title('Welfarist Modified Statistic')
set(t,'Interpreter','Latex','fontsize',16)

set(gcf, 'Position', [0,0,700,300]);

%%% III.II Costly Redistribution correction
figure(2),
plot(beta./(parameters(:,1)-beta),CR_ms_1979,'b-',beta./(parameters(:,1)-beta),CR_ms_aut,'b--','LineWidth',2),hold on,
plot([0.5,0.5],ylim,'k--','LineWidth',1)
text([0.32],[0.8],cellstr('$\varepsilon=0.5$'),'Interpreter','Latex','fontsize',15)
ylim([0.75,1])
xlim([0,1])
set(gca,'FontSize',12)
xl  = xlabel('Elasticity of Taxable Income $\varepsilon$'),
set(xl,'Interpreter','Latex','fontsize',14)
t   = title('Costly Redistribution Modified Statistic')
set(t,'Interpreter','Latex','fontsize',16)
leg = legend(['$d_{1979}$';'$d=\infty$'])
set(leg,'Interpreter','Latex','fontsize',14)

set(gcf, 'Position', [0,0,400,300]);
